@@ -1,5 +1,6 @@
 from pypsql_api.config.types import Session
-from pypsql_api.wire.actions_types import Context, Names
+from pypsql_api.wire.actions_types import Names
+from pypsql_api.context import Context
 from pypsql_api.wire.back import SSLNo, AuthenticationCleartextPassword, ReadyForQuery, AuthenticationOk, \
     EmptyQueryResponse, DataFrameRowDescription, DataFrameDataRows, CommandComplete
 from pypsql_api.wire.front import SSLRequest, StartupMessage, Message, PasswordMessage
@@ -48,7 +49,7 @@ def read_plain_text_password_request(context: Context):
 
     session = context.session
     session.password = m.password
-
+    print(f"Got password {m.password}")
     auth_ok, msg = context.auth_handler.handle(session=session)
 
     if auth_ok:
@@ -81,6 +82,21 @@ def read_receive_command(context: Context):
     return context.update_mem('message', m), m.process_name
 
 
+def read_receive_extended_command(context: Context):
+    m, t = Message.read(context.input)
+
+    print(f">>read_receive_extended_command msg {m}, {t}")
+    if m is None and t is None:
+        print(f"Not m,t  {m}, {t}")
+        return context, None
+
+    if m and m.process_name in {Names.EXECUTE, Names.BIND, Names.SYNC, Names.DESCRIBE}:
+        return context.update_mem('message', m), m.process_name
+
+    print(f"Expected an extended protocol query message but got {m}, {t}")
+    return context, Names.ERROR
+
+
 def write_empty_response(context: Context):
     EmptyQueryResponse().write(context.output)
 
@@ -93,9 +109,13 @@ def write_data_frame_response(context: Context):
         raise Exception("We expect a data frame instance here")
 
     DataFrameRowDescription(df=df).write(context.output)
-    rows = DataFrameDataRows(df=df).write(context.output)
+    rows = DataFrameDataRows(df=df, offset=0, max_rows=1000000).write(context.output)
     CommandComplete(tag=f"SELECT {rows}").write(context.output)
 
     context.output.flush()
 
     return context, Names.READY_FOR_QUERY
+
+
+def read_parse_command(context: Context):
+    m, t = Message.read(context.input)
